#
#    THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
#    5724-xxx (C) COPYRIGHT International Business Machines Corp., 1997, 2011
#    All Rights Reserved * Licensed Materials - Property of IBM
#    US Government Users Restricted Rights - Use, duplication or disclosure
#    restricted by GSA ADP Schedule Contract with IBM Corp.
#
#-------------------------------------------------------------------------------
# This jython script installs the referenced EAR
#-------------------------------------------------------------------------------

def wsadminToList(inStr):
        outList=[]
        if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
                tmpList = inStr[1:-1].split(" ")
        else:
                tmpList = inStr.split("\n")  #splits for Windows or Linux
        for item in tmpList:
                item = item.rstrip();        #removes any Windows "\r"
                if (len(item)>0):
                        outList.append(item)
        return outList
#endDef

#######################################
# installEar subroutine
# location - location where the EAR resides
# earName - name of the ear in the location directory
# appName - name of the Application
# nodeName - name of the WAS node
# serverName - name of the server on the WAS node
#######################################
def installEar ( location, earName, appName, nodeName, serverName):
	print "INFO:  Entering installEar"
	print "INFO:  location="+location+",earName="+earName+",appName="+appName+",nodeName="+nodeName

        #--------------------------------------------------------------
        # set up globals
        #--------------------------------------------------------------
        global AdminConfig
 
        #--------------------------------------------------------------
        # do some sanity checking 
        #     -- do we have a node by this name? 
        #--------------------------------------------------------------
        
        cellname = AdminControl.getCell( )
        node = AdminConfig.getid("/Node:"+nodeName+"/" )
        print "INFO:  checking for existence of node "+nodeName
        if (len(node) == 0):
                print "INFO:  Error -- node not found for name "+nodeName
                return 
        #endIf 

        serverID = AdminConfig.getid("/Node:" + nodeName + "/Server:" + serverName)

        #---------------------------------------------------------
        # First, list the existing applications 
        #---------------------------------------------------------
        apps = AdminApp.list( )
        print "INFO:  Installed applications: "
        print apps

        # Check if App is already installed on the target server
        # Comparing the application name.
        appExist = "False"
        for tmpAppName in wsadminToList(apps):
       	        if (cmp(tmpAppName, appName) == 0):
               	        appExist = "True"
                       	break 
                #endIf 
    	#endFor 
  

        #---------------------------------------------------------
        # Here is the ear file we'll be dealing with... 
        #---------------------------------------------------------
        defapp = location+"/"+earName+".ear"

        #---------------------------------------------------------
        # A very simple install command 
        #---------------------------------------------------------
        if (cmp(appExist, "True") == 0):
                print "WARNING: "+earName+".ear (ApplicationName: "+appName+") is already installed on server."
		print "WARNING: Uninstallation of "+appName+" to begin. "

                # Save current binaries directory
                # import regex component
                import re
                
                global installDir
                app = AdminConfig.getid('/Deployment:WVS-' + nodeName + '/')
                depObj = AdminConfig.showAttribute(app, 'deployedObject')
                binariesURL = AdminConfig.showAttribute(depObj, 'binariesURL')
                regex = "(.*?)\/WVS-.*?\.ear.*"
                cRegex = re.compile(regex)
                match = cRegex.search(binariesURL)
                if match:
                    installDir = match.group(1)
                    print "installDir = " + installDir
                # uninstall the application
                AdminApp.uninstall(appName )

                #check for success
                appExist = "False"
                for tmpAppName in wsadminToList(AdminApp.list()):
                        if (cmp(tmpAppName, appName) == 0):
                                appExist = "True"
                                break 
                        #endIf 
                #endFor 
                if (cmp(appExist, "False") == 0):
                        print "INFO:  Existing Application "+appName+" successfully removed."
                        AdminConfig.save( )
                else:
                        print "ERROR: Existing Application "+appName+" could not be removed."
                #endElse 
        #endIf 

        service = AdminConfig.list("TransactionService", serverID)
        trans_opts = [["transactionLogDirectory", ";0"]]
        AdminConfig.modify(service, trans_opts )
        AdminConfig.save( )

        print "INFO:  Installation of New Application "+appName+" beginning."

        AdminApp.install(defapp, ["-appname", appName, "-node", nodeName, "-server", serverName, "-installed.ear.destination", installDir])

        # check for success
        # cannot do this for wvxjmx as is not visible to wsadmin
        if (cmp(appName, "wvsjmx") != 0):
                appExist = "False"
                for tmpAppName in wsadminToList(AdminApp.list()):
                        if (cmp(tmpAppName, appName) == 0):
                                appExist = "True"
                                break 
                        #endIf 
                #endFor 
                if (cmp(appExist, "True") == 0):
                        print "INFO:  New Application "+appName+" successfully installed."
                        AdminConfig.save( )
                else:
                        print "ERROR: New Application "+appName+" could not be installed."
                #endElse 
        #endIf 

        AdminConfig.save( )
	print "INFO:  Exiting installEar"	        
        return
#endDef 

#-----------------------------------------------------------------
# Main
#-----------------------------------------------------------------
if ((len(sys.argv) != 6)):
        print "installEar: this script requires 6 parameters: scriptname, location of ear, ear, application, node, server"
        print "e.g.:     installEar.py /opt/WebSphere/VoiceServer/ear wvsapp WVS mynode server1"
else:
        installEar(sys.argv[1], sys.argv[2], sys.argv[3], sys.argv[4], sys.argv[5] )
#endif 

